﻿# Miscellaneous example by Jamey Stevenson
# This script demonstrates a variety of different Ren'Py features, including how to set up animations and move things around on screen.
# This script also shows how to prompt the player to input text, store the result in a variable, and display the value stored inside that variable via dialogue.

image bg lecturehall = "lecturehall.jpg"
image bg meadow = "meadow.jpg"
image bg club = "club.jpg"

image Eileen normal = "sylvie_normal.png"

# You can define an animated image using this block format.
image flyingbird:
    "birdfly1.png"
    pause 0.5
    "birdfly2.png"
    pause 0.3
    repeat

# Transforms are used to apply actions such as translation (moving between different locations), rotation and scaling.
transform moveFromLeftToRight:
    align (1.0, 0.0)
    linear 3 xalign 0.0
    linear 2 xalign 1.0
    repeat

# Declare characters used by this game.
define e = Character('Eileen', color="#c8ffc8")
define j = Character('Jamey', color="#293ed7")

# The game starts here.
label start:

    scene bg lecturehall
        
    python:
        didIGoToLectureHall = True
        wisdomPoints = 10
        playerName = "Jane Smith"
        
        # Prompting the user to type their own input must be done via python.
        playerName = renpy.input("What is your name?", "Jane")

    # You can use the 'at' keyword to apply a transform to an image.
    show flyingbird at moveFromLeftToRight
    
    # The pause command will prevent the script from advancing to the next line until the player clicks.
    pause
    
    show Eileen normal
    
    # This line demonstrates how you can use square brackets to display the value of a variable inside a line of dialogue.
    e "Hi, [playerName]! How's it going?"

    e "You've created a new Ren'Py game."

    e "Once you add a story, pictures, and music, you can release it to the world!"
    
    scene bg meadow
    with dissolve
    
    play sound "bloop.wav"
    
    e "Wow, what a transition!"
    
    show Eileen normal at left
    
    e "Hi from the left!"
    
    show Eileen normal at right
    
    e "Hi from the right!"
    
    show Eileen normal at center
    
    e "Hi from the center!"
    
    menu:
        e "Where would you like to go?"
        
        # This line contains a conditional menu option. The button to go to the lecture hall will only appear if the associated condition is true.
        "Go to lecture hall" if playerName == "Jane":
            jump lecturehall
        
        "Go to club room":
            jump clubroom
    
    scene bg lecturehall
    
    pause 3

    return

label lecturehall:
    
    scene bg lecturehall
    with dissolve
    
    show Eileen normal at center
    with dissolve
    
    e "Here we are in the lecture hall!"

    jump shared

    return

label clubroom:
    
    $ didIGoToLectureHall = False
    
    scene bg club
    with dissolve
    
    show Eileen normal at center
    with dissolve
    
    e "Here we are in the club room!"
    
    jump shared
    
    return

label shared:
    scene bg meadow
    with dissolve

    show Eileen normal at center
    with dissolve
    
    if didIGoToLectureHall:
        $ wisdomPoints += 15
        e "The lecture hall isn't too exciting when nobody's there..."
    else:
        $ wisdomPoints += 5
        e "The club room was fun!"
    
    "Wisdom points: [wisdomPoints]"
    
    if wisdomPoints >= 20:
        e "Where do you want to go now, smarty pants?"
    elif wisdomPoints >= 15:
        e "Where do you want to go now?"
    else:
        e "Where do you want to go now, goofball?"





