﻿# Scrolling example by Jamey Stevenson
# This example shows how you can create a background image that the player can scroll by moving their
# mouse over to the screen boundaries. This is done using a viewport, which is the term Ren'Py uses
# for a window that shows a fixed size view into a larger image.

init python:
    # This variable is used to store the persistent value of the viewport offset for the scrolling view.
    # This is also the starting x position of our viewport (the number of pixels from the left
    # side of the background where we start when we first load our scene).
    scrollValue = 1200
    
    # This function is automatically called when the viewport gets scrolled, and it gets passed the new
    # offset value of how far away the viewport's left side is from the background image origin.
    #
    # We use this to force the camera to remain in a fixed position, whereas by default it would snap
    # back to the origin after showing dialogue text or menu choices.
    def storeScrollValue(x):
        global scrollValue
        scrollValue = x

# We need to define our scrolling view inside of a screen.
screen scrollingScene:
    # In order to support scrolling, we need to define all of the images for our scene inside of a viewport.
    viewport:
        # The xadjustment value is used to simultaneously set the initial offset, and provide a callback function
        # that will be invoked when the street viewport is scrolled (in this case, we call storeScrollValue).
        xadjustment adj
        
        # This is an optional value we can set in order to prevent Ren'Py from displaying scrollbars in our viewport.
        scrollbars None
        
        # In order for the scrolling to work, we need to fill in the width and height of background image here.
        child_size(3200, 600)
        
        # This value needs to be set in order for the player to be able to scroll the viewport.
        draggable True
        
        # This value defines the size of the border regions that will cause the viewport to hover when the player
        # moves their mouse toward the screen edges.
        edgescroll(200, 500)

        # Finally, we need to add the actual background image inside of the viewport.
        add "street.png"

# The game starts here.
label start:
    
    $ adj = ui.adjustment(value = scrollValue, changed = storeScrollValue)

    call screen scrollingScene

